[libvirt] [PATCH] Various typos and misspellings

Ján Tomko jtomko at redhat.com
Thu Oct 11 16:31:20 UTC 2012


---
 configure.ac                                       |    2 +-
 daemon/libvirtd.conf                               |    4 ++--
 daemon/stream.c                                    |    2 +-
 docs/api.html.in                                   |    4 ++--
 docs/apibuild.py                                   |    2 +-
 docs/apps.html.in                                  |    2 +-
 docs/firewall.html.in                              |    2 +-
 docs/formatdomain.html.in                          |    2 +-
 docs/hacking.html.in                               |    6 +++---
 docs/internals/locking.html.in                     |    2 +-
 docs/remote.html.in                                |    2 +-
 examples/domain-events/events-python/event-test.py |    4 ++--
 examples/python/dominfo.py                         |    2 +-
 include/libvirt/libvirt.h.in                       |    6 +++---
 src/conf/domain_conf.c                             |    6 +++---
 src/conf/nwfilter_conf.c                           |    2 +-
 src/internal.h                                     |    2 +-
 src/libvirt.c                                      |    4 ++--
 src/phyp/phyp_driver.c                             |    6 +++---
 src/qemu/qemu_capabilities.c                       |    2 +-
 src/qemu/qemu_conf.c                               |    2 +-
 src/qemu/qemu_monitor_text.c                       |    2 +-
 src/qemu/qemu_process.c                            |    2 +-
 src/rpc/virnetsaslcontext.c                        |    2 +-
 src/rpc/virnettlscontext.c                         |    2 +-
 src/storage/storage_backend_disk.c                 |   10 +++++-----
 src/storage/storage_backend_rbd.c                  |    2 +-
 src/uml/uml_driver.c                               |    2 +-
 src/util/cgroup.c                                  |    4 ++--
 src/util/logging.c                                 |    4 ++--
 src/util/processinfo.c                             |    4 ++--
 src/util/virpidfile.c                              |    4 ++--
 src/util/virsocketaddr.c                           |    4 ++--
 src/vbox/vbox_tmpl.c                               |    4 ++--
 src/xen/xm_internal.c                              |    8 ++++----
 src/xenxs/xen_sxpr.c                               |    2 +-
 tests/virnettlscontexttest.c                       |    2 +-
 tools/virsh.pod                                    |    8 ++++----
 38 files changed, 66 insertions(+), 66 deletions(-)

diff --git a/configure.ac b/configure.ac
index ee51bb6..bcdea9c 100644
--- a/configure.ac
+++ b/configure.ac
@@ -1351,7 +1351,7 @@ if test "x$with_avahi" = "xyes" || test "x$with_avahi" = "xcheck"; then
   ])
   if test "x$with_avahi" = "xyes" ; then
     AC_DEFINE_UNQUOTED([HAVE_AVAHI], 1,
-      [whether Avahi is used to broadcast server presense])
+      [whether Avahi is used to broadcast server presence])
   fi
 fi
 AC_SUBST([AVAHI_CFLAGS])
diff --git a/daemon/libvirtd.conf b/daemon/libvirtd.conf
index 3d296cd..47da520 100644
--- a/daemon/libvirtd.conf
+++ b/daemon/libvirtd.conf
@@ -251,7 +251,7 @@
 
 # The minimum limit sets the number of workers to start up
 # initially. If the number of active clients exceeds this,
-# then more threads are spawned, upto max_workers limit.
+# then more threads are spawned, up to max_workers limit.
 # Typically you'd want max_workers to equal maximum number
 # of clients allowed
 #min_workers = 5
@@ -267,7 +267,7 @@
 # at least as large as max_workers. Beyond this, RPC requests
 # will be read into memory and queued. This directly impact
 # memory usage, currently each request requires 256 KB of
-# memory. So by default upto 5 MB of memory is used
+# memory. So by default up to 5 MB of memory is used
 #
 # XXX this isn't actually enforced yet, only the per-client
 # limit is used so far
diff --git a/daemon/stream.c b/daemon/stream.c
index 58c53a9..fa14eeb 100644
--- a/daemon/stream.c
+++ b/daemon/stream.c
@@ -689,7 +689,7 @@ daemonStreamHandleWrite(virNetServerClientPtr client,
 
 /*
  * Invoked when a stream is signalled as having data
- * available to read. This reads upto one message
+ * available to read. This reads up to one message
  * worth of data, and then queues that for transmission
  * to the client.
  *
diff --git a/docs/api.html.in b/docs/api.html.in
index c8fc204..f596aa9 100644
--- a/docs/api.html.in
+++ b/docs/api.html.in
@@ -64,13 +64,13 @@
     <p> Most kind of object can also be named in various ways:</p>
     <ul>
       <li>by their <code>name</code>, an user friendly identifier but
-      whose unicity cannot be garanteed between two nodes.</li>
+      whose unicity cannot be guaranteed between two nodes.</li>
       <li>by their <code>ID</code>, which is a runtime unique identifier
       provided by the hypervisor for one given activation of the object,
       but it becomes invalid once the resource is deactivated.</li >
       <li>by their <code>UUID</code>, a 16 bytes unique identifier
       as defined in <a href="http://www.ietf.org/rfc/rfc4122.txt">RFC 4122</a>,
-      which is garanteed to be unique for long term usage and across a
+      which is guaranteed to be unique for long term usage and across a
       set of nodes.</li>
     </ul>
 
diff --git a/docs/apibuild.py b/docs/apibuild.py
index ae84be9..e73a85d 100755
--- a/docs/apibuild.py
+++ b/docs/apibuild.py
@@ -2474,7 +2474,7 @@ class docBuilder:
 
 def rebuild(name):
     if name not in ["libvirt", "libvirt-qemu"]:
-        self.warning("rebuild() failed, unkown module %s") % name
+        self.warning("rebuild() failed, unknown module %s") % name
         return None
     builder = None
     srcdir = os.environ["srcdir"]
diff --git a/docs/apps.html.in b/docs/apps.html.in
index 903b099..76020d8 100644
--- a/docs/apps.html.in
+++ b/docs/apps.html.in
@@ -188,7 +188,7 @@
         A general purpose desktop management tool, able to manage
         virtual machines across both local and remotely accessed
         hypervisors. It is targeted at home and small office usage
-        upto managing 10-20 hosts and their VMs.
+        up to managing 10-20 hosts and their VMs.
       </dd>
       <dt><a href="http://virt-manager.org/">virt-viewer</a></dt>
       <dd>
diff --git a/docs/firewall.html.in b/docs/firewall.html.in
index 8af3dd3..afc8dd3 100644
--- a/docs/firewall.html.in
+++ b/docs/firewall.html.in
@@ -317,7 +317,7 @@ Bridge chain: PREROUTING, entries: 1, policy: ACCEPT
 
 Bridge chain: POSTROUTING, entries: 1, policy: ACCEPT
 -o vnet0 -j libvirt-O-vnet0</pre>
-    <p>To keep things managable and easy to follow, the driver will then
+    <p>To keep things manageable and easy to follow, the driver will then
        create further sub-chains for each protocol then it needs to match
        against:
     </p>
diff --git a/docs/formatdomain.html.in b/docs/formatdomain.html.in
index a622131..d664e7e 100644
--- a/docs/formatdomain.html.in
+++ b/docs/formatdomain.html.in
@@ -425,7 +425,7 @@
        <dd>
          The optional <code>emulatorpin</code> element specifies which of host
          physical CPUs the "emulator", a subset of a domain not including vcpu,
-         will be pinned to. If this is ommitted, "emulator" is pinned to all
+         will be pinned to. If this is omitted, "emulator" is pinned to all
          the physical CPUs by default. It contains one required attribute
          <code>cpuset</code> specifying which physical CPUs to pin to.
        </dd>
diff --git a/docs/hacking.html.in b/docs/hacking.html.in
index 9de5eb1..d41b39c 100644
--- a/docs/hacking.html.in
+++ b/docs/hacking.html.in
@@ -18,7 +18,7 @@
           or:
         </p>
 <pre>
-  git diff > libvirt-myfeature.patch
+  git diff > libvirt-myfeature.patch
 </pre>
         <p>However, the usual workflow of libvirt developer is:</p>
 <pre>
@@ -554,8 +554,8 @@
     <p>
       Usage of the <code>fdopen()</code>, <code>close()</code>, <code>fclose()</code>
       APIs is deprecated in libvirt code base to help avoiding double-closing of files
-      or file descriptors, which is particulary dangerous in a multi-threaded
-      applications. Instead of these APIs, use the macros from virfile.h
+      or file descriptors, which is particularly dangerous in a multi-threaded
+      application. Instead of these APIs, use the macros from virfile.h
     </p>
 
    <ul>
diff --git a/docs/internals/locking.html.in b/docs/internals/locking.html.in
index 34e50c7..c50e68f 100644
--- a/docs/internals/locking.html.in
+++ b/docs/internals/locking.html.in
@@ -150,7 +150,7 @@
     <h2><a name="usagePatterns">Lock usage patterns</a></h2>
 
     <p>
-      The following psuedo code illustrates the common
+      The following pseudo code illustrates the common
       patterns of operations invoked on the lock
       manager plugin callbacks.
     </p>
diff --git a/docs/remote.html.in b/docs/remote.html.in
index 40696b9..fc6af82 100644
--- a/docs/remote.html.in
+++ b/docs/remote.html.in
@@ -356,7 +356,7 @@ Note that parameter values must be
         </td>
         <td> libssh2 </td>
         <td>
-  Path to the known_hosts file to verify the host key agains. LibSSH2
+  Path to the known_hosts file to verify the host key against. LibSSH2
   supports OpenSSH-style known_hosts files, although it does not support
   all key types, so using files created by the OpenSSH binary may result
   into truncating the known_hosts file. It's recommended to use the default
diff --git a/examples/domain-events/events-python/event-test.py b/examples/domain-events/events-python/event-test.py
index 3e314bf..27e74c4 100644
--- a/examples/domain-events/events-python/event-test.py
+++ b/examples/domain-events/events-python/event-test.py
@@ -126,7 +126,7 @@ class virEventLoopPure:
         self.poll.register(self.pipetrick[0], select.POLLIN)
 
 
-    # Calculate when the next timeout is due to occurr, returning
+    # Calculate when the next timeout is due to occur, returning
     # the absolute timestamp for the next timeout, or 0 if there is
     # no timeout due
     def next_timeout(self):
@@ -169,7 +169,7 @@ class virEventLoopPure:
     #
     # Due to the coarse granularity of schedular timeslices, if
     # we ask for a sleep of 500ms in order to satisfy a timer, we
-    # may return upto 1 schedular timeslice early. So even though
+    # may return up to 1 schedular timeslice early. So even though
     # our sleep timeout was reached, the registered timer may not
     # technically be at its expiry point. This leads to us going
     # back around the loop with a crazy 5ms sleep. So when checking
diff --git a/examples/python/dominfo.py b/examples/python/dominfo.py
index 033fe47..0d3238b 100755
--- a/examples/python/dominfo.py
+++ b/examples/python/dominfo.py
@@ -43,7 +43,7 @@ try:
     dom = conn.lookupByName(name)
     # Annoyiingly, libvirt prints its own error message here
 except libvirt.libvirtError:
-    print "Domain %s is not runing" % name
+    print "Domain %s is not running" % name
     sys.exit(0)
 
 info = dom.info()
diff --git a/include/libvirt/libvirt.h.in b/include/libvirt/libvirt.h.in
index b1a3e25..a4e8ca9 100644
--- a/include/libvirt/libvirt.h.in
+++ b/include/libvirt/libvirt.h.in
@@ -3124,7 +3124,7 @@ typedef enum {
  * virConnectDomainEventCallback:
  * @conn: virConnect connection
  * @dom: The domain on which the event occurred
- * @event: The specfic virDomainEventType which occurred
+ * @event: The specific virDomainEventType which occurred
  * @detail: event specific detail information
  * @opaque: opaque user data
  *
@@ -3417,7 +3417,7 @@ int virStreamRecv(virStreamPtr st,
  *
  * The callback will be invoked multiple times,
  * fetching data in small chunks. The application
- * should fill the 'data' array with upto 'nbytes'
+ * should fill the 'data' array with up to 'nbytes'
  * of data and then return the number actual number
  * of bytes. The callback will continue to be
  * invoked until it indicates the end of the source
@@ -3849,7 +3849,7 @@ typedef void (*virConnectDomainEventWatchdogCallback)(virConnectPtr conn,
 /**
  * virDomainEventIOErrorAction:
  *
- * The action that is to be taken due to an IO error occuring
+ * The action that is to be taken due to an IO error occurring
  */
 typedef enum {
     VIR_DOMAIN_EVENT_IO_ERROR_NONE = 0,  /* No action, IO error ignored */
diff --git a/src/conf/domain_conf.c b/src/conf/domain_conf.c
index 1eda551..3c3d0ae 100644
--- a/src/conf/domain_conf.c
+++ b/src/conf/domain_conf.c
@@ -4668,7 +4668,7 @@ virDomainActualNetDefParseXML(xmlNodePtr node,
             int m;
             if ((m = virNetDevMacVLanModeTypeFromString(mode)) < 0) {
                 virReportError(VIR_ERR_INTERNAL_ERROR,
-                               _("Unkown mode '%s' in interface <actual> element"),
+                               _("Unknown mode '%s' in interface <actual> element"),
                                mode);
                 goto error;
             }
@@ -5036,7 +5036,7 @@ virDomainNetDefParseXML(virCapsPtr caps,
             int m;
             if ((m = virNetDevMacVLanModeTypeFromString(mode)) < 0) {
                 virReportError(VIR_ERR_INTERNAL_ERROR, "%s",
-                               _("Unkown mode has been specified"));
+                               _("Unknown mode has been specified"));
                 goto error;
             }
             def->data.direct.mode = m;
@@ -7042,7 +7042,7 @@ virDomainVideoDefaultRAM(virDomainDefPtr def,
                          int type)
 {
     switch (type) {
-        /* Wierd, QEMU defaults to 9 MB ??! */
+        /* Weird, QEMU defaults to 9 MB ??! */
     case VIR_DOMAIN_VIDEO_TYPE_VGA:
     case VIR_DOMAIN_VIDEO_TYPE_CIRRUS:
     case VIR_DOMAIN_VIDEO_TYPE_VMVGA:
diff --git a/src/conf/nwfilter_conf.c b/src/conf/nwfilter_conf.c
index d1d5259..27dbee8 100644
--- a/src/conf/nwfilter_conf.c
+++ b/src/conf/nwfilter_conf.c
@@ -2801,7 +2801,7 @@ _virNWFilterDefLoopDetect(virConnectPtr conn,
  * virNWFilterDefLoopDetect:
  * @conn: pointer to virConnect object
  * @nwfilters : the nwfilters to search
- * @def : the filter definiton that may add a loop and is to be tested
+ * @def : the filter definition that may add a loop and is to be tested
  *
  * Detect a loop introduced through the filters being able to
  * reference each other.
diff --git a/src/internal.h b/src/internal.h
index 77210e5..d69bd14 100644
--- a/src/internal.h
+++ b/src/internal.h
@@ -107,7 +107,7 @@
 /**
  * ATTRIBUTE_UNUSED:
  *
- * Macro to flag conciously unused parameters to functions
+ * Macro to flag consciously unused parameters to functions
  */
 #  ifndef ATTRIBUTE_UNUSED
 #   define ATTRIBUTE_UNUSED __attribute__((__unused__))
diff --git a/src/libvirt.c b/src/libvirt.c
index 76e4401..3c6d67d 100644
--- a/src/libvirt.c
+++ b/src/libvirt.c
@@ -3091,7 +3091,7 @@ error:
  *
  * This call sets up a stream; subsequent use of stream API is necessary
  * to transfer actual data, determine how much data is successfully
- * transfered, and detect any errors.
+ * transferred, and detect any errors.
  *
  * The screen ID is the sequential number of screen. In case of multiple
  * graphics cards, heads are enumerated before devices, e.g. having
@@ -14683,7 +14683,7 @@ error:
  * @cb: callback to the function handling domain events
  *
  * Removes a callback previously registered with the virConnectDomainEventRegister
- * funtion.
+ * function.
  *
  * Use of this method is no longer recommended. Instead applications
  * should try virConnectDomainEventUnregisterAny which has a more flexible
diff --git a/src/phyp/phyp_driver.c b/src/phyp/phyp_driver.c
index 733f455..a1724ca 100644
--- a/src/phyp/phyp_driver.c
+++ b/src/phyp/phyp_driver.c
@@ -2064,7 +2064,7 @@ phypStorageVolCreateXML(virStoragePoolPtr pool,
         goto err;
     }
 
-    /* Information not avaliable */
+    /* Information not available */
     spdef->allocation = 0;
     spdef->available = 0;
 
@@ -2287,7 +2287,7 @@ phypVolumeGetXMLDesc(virStorageVolPtr vol, unsigned int flags)
         goto cleanup;
     }
 
-    /* Information not avaliable */
+    /* Information not available */
     pool.allocation = 0;
     pool.available = 0;
 
@@ -2767,7 +2767,7 @@ phypGetStoragePoolXMLDesc(virStoragePoolPtr pool, unsigned int flags)
         goto err;
     }
 
-    /* Information not avaliable */
+    /* Information not available */
     def.allocation = 0;
     def.available = 0;
 
diff --git a/src/qemu/qemu_capabilities.c b/src/qemu/qemu_capabilities.c
index 05340ae..fb0fe54 100644
--- a/src/qemu/qemu_capabilities.c
+++ b/src/qemu/qemu_capabilities.c
@@ -607,7 +607,7 @@ qemuCapsInitGuest(virCapsPtr caps,
     qemuCapsPtr kvmbinCaps = NULL;
     int ret = -1;
 
-    /* Check for existance of base emulator, or alternate base
+    /* Check for existence of base emulator, or alternate base
      * which can be used with magic cpu choice
      */
     binary = qemuCapsFindBinaryForArch(hostarch, guestarch);
diff --git a/src/qemu/qemu_conf.c b/src/qemu/qemu_conf.c
index 9a2c39b..8f3922f 100644
--- a/src/qemu/qemu_conf.c
+++ b/src/qemu/qemu_conf.c
@@ -203,7 +203,7 @@ int qemudLoadDriverConfig(struct qemud_driver *driver,
         size_t len;
         virConfValuePtr pp;
 
-        /* Calc lenght and check items */
+        /* Calc length and check items */
         for (len = 0, pp = p->list; pp; len++, pp = pp->next) {
             if (pp->type != VIR_CONF_STRING) {
                 VIR_ERROR(_("security_driver be a list of strings"));
diff --git a/src/qemu/qemu_monitor_text.c b/src/qemu/qemu_monitor_text.c
index 7f5c3e3..09f2a92 100644
--- a/src/qemu/qemu_monitor_text.c
+++ b/src/qemu/qemu_monitor_text.c
@@ -2291,7 +2291,7 @@ int qemuMonitorTextGetPtyPaths(qemuMonitorPtr mon,
         if (!needle)
             continue;
 
-        /* id is everthing from the beginning of the line to the ':'
+        /* id is everything from the beginning of the line to the ':'
          * find ':' and turn it into a terminator */
         char *colon = memchr(pos, ':', needle - pos);
         if (colon == NULL)
diff --git a/src/qemu/qemu_process.c b/src/qemu/qemu_process.c
index 3bec799..f8a2bfd 100644
--- a/src/qemu/qemu_process.c
+++ b/src/qemu/qemu_process.c
@@ -2599,7 +2599,7 @@ static int qemuProcessHook(void *data)
     if (virDomainLockProcessStart(h->driver->lockManager,
                                   h->driver->uri,
                                   h->vm,
-                                  /* QEMU is always pased initially */
+                                  /* QEMU is always paused initially */
                                   true,
                                   &fd) < 0)
         goto cleanup;
diff --git a/src/rpc/virnetsaslcontext.c b/src/rpc/virnetsaslcontext.c
index e65ff6f..7ed1e39 100644
--- a/src/rpc/virnetsaslcontext.c
+++ b/src/rpc/virnetsaslcontext.c
@@ -150,7 +150,7 @@ int virNetSASLContextCheckIdentity(virNetSASLContextPtr ctxt,
         int rv = fnmatch (*wildcards, identity, 0);
         if (rv == 0) {
             ret = 1;
-            goto cleanup; /* Succesful match */
+            goto cleanup; /* Successful match */
         }
         if (rv != FNM_NOMATCH) {
             virReportError(VIR_ERR_INTERNAL_ERROR,
diff --git a/src/rpc/virnettlscontext.c b/src/rpc/virnettlscontext.c
index 9769969..0c89a54 100644
--- a/src/rpc/virnettlscontext.c
+++ b/src/rpc/virnettlscontext.c
@@ -374,7 +374,7 @@ virNetTLSContextCheckCertDNWhitelist(const char *dname,
 {
     while (*wildcards) {
         int ret = fnmatch (*wildcards, dname, 0);
-        if (ret == 0) /* Succesful match */
+        if (ret == 0) /* Successful match */
             return 1;
         if (ret != FNM_NOMATCH) {
             virReportError(VIR_ERR_INTERNAL_ERROR,
diff --git a/src/storage/storage_backend_rbd.c b/src/storage/storage_backend_rbd.c
index 767892f..0c9bdcc 100644
--- a/src/storage/storage_backend_rbd.c
+++ b/src/storage/storage_backend_rbd.c
@@ -315,7 +315,7 @@ static int virStorageBackendRBDRefreshPool(virConnectPtr conn ATTRIBUTE_UNUSED,
         if (len >= 0)
             break;
         if (len != -ERANGE) {
-            VIR_WARN("%s", _("A problem occured while listing RBD images"));
+            VIR_WARN("%s", _("A problem occurred while listing RBD images"));
             goto cleanup;
         }
     }
diff --git a/src/uml/uml_driver.c b/src/uml/uml_driver.c
index c341fab..ba37eb7 100644
--- a/src/uml/uml_driver.c
+++ b/src/uml/uml_driver.c
@@ -258,7 +258,7 @@ requery:
         }
     } else if (!res || STRPREFIX(res, "pts")) {
         /* It can take a while to startup, so retry for
-           upto 5 seconds */
+           up to 5 seconds */
         /* XXX should do this in a better non-blocking
            way somehow ...perhaps register a timer */
         if (retries++ < 50) {
diff --git a/src/util/cgroup.c b/src/util/cgroup.c
index 0825801..3f7b5f7 100644
--- a/src/util/cgroup.c
+++ b/src/util/cgroup.c
@@ -169,7 +169,7 @@ no_memory:
 /*
  * Process /proc/self/cgroup figuring out what cgroup
  * sub-path the current process is assigned to. ie not
- * neccessarily in the root
+ * necessarily in the root
  */
 static int virCgroupDetectPlacement(virCgroupPtr group)
 {
@@ -2026,7 +2026,7 @@ int virCgroupKillPainfully(virCgroupPtr group)
         else if (i == 8)
             signum = SIGKILL;
         else
-            signum = 0; /* Just check for existance */
+            signum = 0; /* Just check for existence */
 
         rc = virCgroupKillRecursive(group, signum);
         VIR_DEBUG("Iteration %d rc=%d", i, rc);
diff --git a/src/util/logging.c b/src/util/logging.c
index 246f12c..9a8bba1 100644
--- a/src/util/logging.c
+++ b/src/util/logging.c
@@ -1081,7 +1081,7 @@ virLogOutputToJournald(virLogSource source,
     char priostr[INT_BUFSIZE_BOUND(priority)];
     char linestr[INT_BUFSIZE_BOUND(linenr)];
 
-    /* First message takes upto 4 iovecs, and each
+    /* First message takes up to 4 iovecs, and each
      * other field needs 3, assuming they don't have
      * newlines in them
      */
@@ -1090,7 +1090,7 @@ virLogOutputToJournald(virLogSource source,
 
     if (strchr(rawstr, '\n')) {
         uint64_t nstr;
-        /* If 'str' containes a newline, then we must
+        /* If 'str' contains a newline, then we must
          * encode the string length, since we can't
          * rely on the newline for the field separator
          */
diff --git a/src/util/processinfo.c b/src/util/processinfo.c
index d4f8f4b..c3648d4 100644
--- a/src/util/processinfo.c
+++ b/src/util/processinfo.c
@@ -77,7 +77,7 @@ realloc:
     }
     CPU_FREE(mask);
 # else
-    /* Legacy method uses a fixed size cpu mask, only allows upto 1024 cpus */
+    /* Legacy method uses a fixed size cpu mask, only allows up to 1024 cpus */
     cpu_set_t mask;
 
     CPU_ZERO(&mask);
@@ -149,7 +149,7 @@ realloc:
             ignore_value(virBitmapSetBit(*map, i));
     CPU_FREE(mask);
 # else
-    /* Legacy method uses a fixed size cpu mask, only allows upto 1024 cpus */
+    /* Legacy method uses a fixed size cpu mask, only allows up to 1024 cpus */
     cpu_set_t mask;
 
     CPU_ZERO(&mask);
diff --git a/src/util/virpidfile.c b/src/util/virpidfile.c
index e8434c1..c2a087d 100644
--- a/src/util/virpidfile.c
+++ b/src/util/virpidfile.c
@@ -366,7 +366,7 @@ int virPidFileAcquirePath(const char *path,
             VIR_DEBUG("Pid file '%s' disappeared: %s",
                       path, virStrerror(errno, ebuf, sizeof(ebuf)));
             VIR_FORCE_CLOSE(fd);
-            /* Someone else must be racing with us, so try agin */
+            /* Someone else must be racing with us, so try again */
             continue;
         }
 
@@ -375,7 +375,7 @@ int virPidFileAcquirePath(const char *path,
 
         VIR_DEBUG("Pid file '%s' was recreated", path);
         VIR_FORCE_CLOSE(fd);
-        /* Someone else must be racing with us, so try agin */
+        /* Someone else must be racing with us, so try again */
     }
 
     snprintf(pidstr, sizeof(pidstr), "%lld", (long long) pid);
diff --git a/src/util/virsocketaddr.c b/src/util/virsocketaddr.c
index 7f49b40..e9ebac8 100644
--- a/src/util/virsocketaddr.c
+++ b/src/util/virsocketaddr.c
@@ -418,7 +418,7 @@ virSocketAddrMaskByPrefix(const virSocketAddrPtr addr,
  * virSocketAddrBroadcast:
  * @addr: address that needs to be turned into broadcast address (IPv4 only)
  * @netmask: the netmask address
- * @broadcast: virSocketAddr to recieve the broadcast address
+ * @broadcast: virSocketAddr to receive the broadcast address
  *
  * Mask ON the host bits of @addr according to @netmask, turning it
  * into a broadcast address.
@@ -448,7 +448,7 @@ virSocketAddrBroadcast(const virSocketAddrPtr addr,
  * virSocketAddrBroadcastByPrefix:
  * @addr: address that needs to be turned into broadcast address (IPv4 only)
  * @prefix: prefix (# of 1 bits) of netmask to apply
- * @broadcast: virSocketAddr to recieve the broadcast address
+ * @broadcast: virSocketAddr to receive the broadcast address
  *
  * Mask off the host bits of @addr according to @prefix, turning it
  * into a network address.
diff --git a/src/vbox/vbox_tmpl.c b/src/vbox/vbox_tmpl.c
index 29b776d..0eeac85 100644
--- a/src/vbox/vbox_tmpl.c
+++ b/src/vbox/vbox_tmpl.c
@@ -7049,7 +7049,7 @@ vboxCallbackOnMachineRegistered(IVirtualBoxCallback *pThis ATTRIBUTE_UNUSED,
             virDomainEventPtr ev;
 
             /* CURRENT LIMITATION: we never get the VIR_DOMAIN_EVENT_UNDEFINED
-             * event becuase the when the machine is de-registered the call
+             * event because the when the machine is de-registered the call
              * to vboxDomainLookupByUUID fails and thus we don't get any
              * dom pointer which is necessary (null dom pointer doesn't work)
              * to show the VIR_DOMAIN_EVENT_UNDEFINED event
@@ -8747,7 +8747,7 @@ static int vboxStorageVolDelete(virStorageVolPtr vol,
              * is no 128bit width simple item type for a SafeArray to fit a
              * GUID in. The largest simple type it 64bit width and VirtualBox
              * uses two of this 64bit items to represents one GUID. Therefore,
-             * we devide the size of the SafeArray by two, to compensate for
+             * we divide the size of the SafeArray by two, to compensate for
              * this workaround in VirtualBox */
             machineIds.count /= 2;
 #endif /* VBOX_API_VERSION >= 2002 */
diff --git a/src/xen/xm_internal.c b/src/xen/xm_internal.c
index 5911554..7b3d340 100644
--- a/src/xen/xm_internal.c
+++ b/src/xen/xm_internal.c
@@ -174,7 +174,7 @@ xenXMConfigSaveFile(virConnectPtr conn, const char *filename, virDomainDefPtr de
 
 /*
  * Caller must hold the lock on 'conn->privateData' before
- * calling this funtion
+ * calling this function
  */
 int
 xenXMConfigCacheRemoveFile(virConnectPtr conn,
@@ -198,7 +198,7 @@ xenXMConfigCacheRemoveFile(virConnectPtr conn,
 
 /*
  * Caller must hold the lock on 'conn->privateData' before
- * calling this funtion
+ * calling this function
  */
 int
 xenXMConfigCacheAddFile(virConnectPtr conn, const char *filename)
@@ -307,7 +307,7 @@ xenXMConfigCacheAddFile(virConnectPtr conn, const char *filename)
  * once every X seconds
  *
  * Caller must hold the lock on 'conn->privateData' before
- * calling this funtion
+ * calling this function
  */
 int xenXMConfigCacheRefresh (virConnectPtr conn) {
     xenUnifiedPrivatePtr priv = conn->privateData;
@@ -383,7 +383,7 @@ int xenXMConfigCacheRefresh (virConnectPtr conn) {
         /* If we already have a matching entry and it is not
            modified, then carry on to next one*/
         if (xenXMConfigCacheAddFile(conn, path) < 0) {
-            /* Ignoring errors, since alot of stuff goes wrong in /etc/xen */
+            /* Ignoring errors, since a lot of stuff goes wrong in /etc/xen */
         }
 
         VIR_FREE(path);
diff --git a/src/xenxs/xen_sxpr.c b/src/xenxs/xen_sxpr.c
index df92702..6ac7dff 100644
--- a/src/xenxs/xen_sxpr.c
+++ b/src/xenxs/xen_sxpr.c
@@ -811,7 +811,7 @@ xenParseSxprGraphicsOld(virDomainDefPtr def,
         /* For Xen >= 3.0.3, don't generate a fixed port mapping
          * because it will almost certainly be wrong ! Just leave
          * it as -1 which lets caller see that the VNC server isn't
-         * present yet. Subsquent dumps of the XML will eventually
+         * present yet. Subsequent dumps of the XML will eventually
          * find the port in XenStore once VNC server has started
          */
         if (port == -1 && xendConfigVersion < XEND_CONFIG_VERSION_3_0_3)
diff --git a/tests/virnettlscontexttest.c b/tests/virnettlscontexttest.c
index 80204b6..cc260e0 100644
--- a/tests/virnettlscontexttest.c
+++ b/tests/virnettlscontexttest.c
@@ -448,7 +448,7 @@ struct testTLSContextData {
  * This code is done when libvirtd starts up, or before
  * a libvirt client connects. The test is ensuring that
  * the creation of virNetTLSContextPtr fails if we
- * give bogus certs, or suceeds for good certs
+ * give bogus certs, or succeeds for good certs
  */
 static int testTLSContextInit(const void *opaque)
 {
diff --git a/tools/virsh.pod b/tools/virsh.pod
index ea5060c..2d90b7b 100644
--- a/tools/virsh.pod
+++ b/tools/virsh.pod
@@ -129,7 +129,7 @@ Several B<virsh> commands take an optionally scaled integer; if no
 scale is provided, then the default is listed in the command (for
 historical reasons, some commands default to bytes, while other
 commands default to kibibytes).  The following case-insensitive
-suffixes can be used to select a specfic scale:
+suffixes can be used to select a specific scale:
   b, byte  byte      1
   KB       kilobyte  1,000
   k, KiB   kibibyte  1,024
@@ -607,7 +607,7 @@ Availability of these fields depends on hypervisor. Unsupported fields are
 missing from the output. Other fields may appear if communicating with a newer
 version of libvirtd.
 
-B<Explanation of fields> (fields appear in the folowing order):
+B<Explanation of fields> (fields appear in the following order):
   rd_req            - count of read operations
   rd_bytes          - count of read bytes
   wr_req            - count of write operations
@@ -2406,7 +2406,7 @@ is in.
 I<vol-name-or-key-or-path> is the name or key or path of the volume to wipe.
 I<--offset> is the position in the storage volume at which to start writing
 the data. I<--length> is an upper bound of the amount of data to be uploaded.
-An error will occurr if the I<local-file> is greater than the specified length.
+An error will occur if the I<local-file> is greater than the specified length.
 
 =item B<vol-download> [I<--pool> I<pool-or-uuid>] [I<--offset> I<bytes>]
 [I<--length> I<bytes>] I<vol-name-or-key-or-path> I<local-file>
@@ -2654,7 +2654,7 @@ this flag is in use, the command can also take additional I<diskspec>
 arguments to add <disk> elements to the xml.  Each <diskspec> is in the
 form B<disk[,snapshot=type][,driver=type][,file=name]>.  To include a
 literal comma in B<disk> or in B<file=name>, escape it with a second
-comma.  A literal I<--diskspec> must preceed each B<diskspec> unless
+comma.  A literal I<--diskspec> must precede each B<diskspec> unless
 all three of I<domain>, I<name>, and I<description> are also present.
 For example, a diskspec of "vda,snapshot=external,file=/path/to,,new"
 results in the following XML:
diff --git a/src/storage/storage_backend_disk.c b/src/storage/storage_backend_disk.c
index ceceab0..5d9e72f 100644
--- a/src/storage/storage_backend_disk.c
+++ b/src/storage/storage_backend_disk.c
@@ -533,9 +533,9 @@ virStorageBackendDiskPartFormat(virStoragePoolObjPtr pool,
 }
 
 /**
  * Aligns a new partition to nearest cylinder boundry
  * when having a msdos partition table type
- * to avoid any problem with all ready existing
+ * to avoid any problem with already existing
  * partitions
  */
 static int
@@ -558,7 +558,7 @@ virStorageBackendDiskPartBoundries(virStoragePoolObjPtr pool,
     int partType = virStorageBackendDiskPartTypeToCreate(pool);
 
     /* how many extra bytes we have since we allocate
-       aligned to the cylinder boundry */
+       aligned to the cylinder boundary */
     extraBytes = cylinderSize - (allocation % cylinderSize);
 
     for (i = 0 ; i < dev->nfreeExtent ; i++) {
@@ -568,7 +568,7 @@ virStorageBackendDiskPartBoundries(virStoragePoolObjPtr pool,
          unsigned long long neededSize = allocation;
 
          if (pool->def->source.format == VIR_STORAGE_POOL_DISK_DOS) {
              /* align to cylinder boundry */
              neededSize += extraBytes;
              if ((*start % cylinderSize) > extraBytes) {
                  /* add an extra cylinder if the offset can't fit within
@@ -617,7 +617,7 @@ virStorageBackendDiskPartBoundries(virStoragePoolObjPtr pool,
 
     *end = *start + alignedAllocation;
     if (pool->def->source.format == VIR_STORAGE_POOL_DISK_DOS) {
         /* adjust our allocation if start is not at a cylinder boundry */
         *end -= (*start % cylinderSize);
     }
 
@@ -533,9 +533,9 @@ virStorageBackendDiskPartFormat(virStoragePoolObjPtr pool,
 
 /**
- * Aligns a new partition to nearest cylinder boundry
+ * Aligns a new partition to nearest cylinder boundary
  * when having a msdos partition table type
@@ -568,7 +568,7 @@ virStorageBackendDiskPartBoundries(virStoragePoolObjPtr pool,
 
          if (pool->def->source.format == VIR_STORAGE_POOL_DISK_DOS) {
-             /* align to cylinder boundry */
+             /* align to cylinder boundary */
              neededSize += extraBytes;
              if ((*start % cylinderSize) > extraBytes) {
@@ -617,7 +617,7 @@ virStorageBackendDiskPartBoundries(virStoragePoolObjPtr pool,
     *end = *start + alignedAllocation;
     if (pool->def->source.format == VIR_STORAGE_POOL_DISK_DOS) {
-        /* adjust our allocation if start is not at a cylinder boundry */
+        /* adjust our allocation if start is not at a cylinder boundary */
         *end -= (*start % cylinderSize);
     }
-- 
1.7.8.6




More information about the libvir-list mailing list